@@ -41,8 +41,6 @@
 #define LOGIN1_SERVICE "org.freedesktop.login1"
 #define CONSOLEKIT2_SERVICE "org.freedesktop.ConsoleKit"
 
-class XRandRXCBHelper;
-class XRandrBrightness;
 class QPropertyAnimation;
 class QTimer;
 class DDCutilBrightness;
@@ -99,8 +97,6 @@ private:
 
     // brightness
     QMap<BrightnessControlType, int> m_cachedBrightnessMap;
-    XRandrBrightness         *m_brightnessControl;
-    XRandRXCBHelper *m_randrHelper;
     DDCutilBrightness *m_ddcBrightnessControl;
 
     OrgFreedesktopUPowerInterface *m_upowerInterface;
