@@ -32,8 +32,8 @@ class Q_DECL_EXPORT ActionConfigWidget : public QWidget
 {
 Q_OBJECT
 public:
-    ActionConfigWidget(QWidget* parent);
-    ~ActionConfigWidget();
+    explicit ActionConfigWidget(QWidget* parent);
+    ~ActionConfigWidget() override;
 
     void addWidgets(QList<QPair <QString, QWidget*> > configMap);
 
